<?php
/**
 * List the different types of scoring methods throughout all the games
 * @return unknown_type
 */
function leaguesite_methods_list(){
  $methods = db_query("SELECT * FROM {leaguesite_method};");
  $count = 0;

  while($row = db_fetch_array($methods)){
    $form[$row['method_id']]['name'] = array('#value' => $row['name'],);
    $form[$row['method_id']]['points'] = array('#value' => $row['points']);
    $form[$row['method_id']]['configure'] = array('#value' => l(t('configure'), 'admin/content/leaguesite/methods/'.$row['method_id'].'/edit'));
    $form[$row['method_id']]['delete'] = array('#value' => $default ? '' : l(t('delete'), 'admin/content/leaguesite/methods/'.$row['method_id'].'/delete'));
    ++$count;
  }
  if($count == 0){
    $form['notice'] = array('#value' => 'No scoring types currently exist.');
  }


  return $form;
}

/**
 * Theme the table of scoring methods
 * @return unknown_type
 */
function theme_leaguesite_methods_list($form){
  $scorerows = array();
  foreach ($form as $name => $element) {
    if(is_array($element['name'])){
      $scorerows[] = array(
      drupal_render($element['name']),
      drupal_render($element['points']),
      drupal_render($element['configure']),
      drupal_render($element['delete'])
      );
      unset($form[$name]);
    }
  }
  $seasonheader = array(t('Method Name'), t('Points'), array('data' => t('Operations'), 'colspan' => 2));
  if(count($scorerows) > 0){
    $output = theme('table', $seasonheader, $scorerows);
  }
  $output .= l('Add a new score method', 'admin/content/leaguesite/methods/add');
  return $output;
}

function leaguesite_score_method_add(){
	$form = array();
  //add a new season
  $form['method_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#description' => t('The name of the score method, e.g. penalty'),
    '#size' => 30,
    '#maxlength' => 50,
    '#required' => TRUE,
  );

  $form['method_points'] = array(
    '#type' => 'textfield',
    '#title' => t('Value'),  
    '#description' => t('How many points is the score method worth?'),
    '#size' => 4,
    '#maxlength' => 4,
    '#required' => TRUE,
  );
  $form['submit'] = array(
    '#type' => 'submit', '#value' => t('Create Scoring Method')
  );
  return $form;
}

function leaguesite_score_method_add_submit($form, $form_state){
	$name = check_plain($form_state['values']['method_name']);
	db_query("INSERT INTO {leaguesite_method} (name, points) VALUES ('%s', '%d');", $form_state['values']['method_name'], $form_state['values']['method_points']);
	drupal_set_message(t('Added score method %method.', array('%method' => $name)));
}

function leaguesite_score_method_edit(){
	//add breadcrumb for easy navigation back
	$breadcrumb = drupal_get_breadcrumb();
  $breadcrumb[] = l(t('Methods'), 'admin/content/leaguesite/methods/list');
  drupal_set_breadcrumb($breadcrumb);
  
	$method = arg(4);
  if(is_numeric($method)){
    $result = db_fetch_array(db_query("SELECT * FROM {leaguesite_method} WHERE method_id = %d", $method));
	  $form = array();
    //add a new season
    $form['method_name'] = array(
      '#type' => 'textfield',
      '#title' => t('Name'),
      '#description' => t('The name of the score method, e.g. penalty'),
      '#size' => 30,
      '#maxlength' => 50,
      '#required' => TRUE,
      '#default_value' => $result['name'],
    );
    $form['method_points'] = array(
      '#type' => 'textfield',
      '#title' => t('Value'),  
      '#description' => t('How many points is the score method worth?'),
      '#size' => 4,
      '#maxlength' => 4,
      '#required' => TRUE,
      '#default_value' => $result['points'],
    );
    $form['submit'] = array(
      '#type' => 'submit', '#value' => t('Amend Scoring Method')
    );
  }
  return $form;
}

/**
 * Form that confirms the deletion of the score method
 */
function leaguesite_score_method_delete(){
  $method = arg(4);
  $method = db_fetch_array(db_query('SELECT * FROM {leaguesite_method} WHERE method_id = %d;', $method));
  if ($method) {
    $form['method'] = array('#type' => 'hidden', '#value' => $method['method_id']);
    $form['name'] = array('#type' => 'hidden', '#value' => $method['name']);
    return confirm_form($form, t('Are you sure you want to delete the score method %method?', array('%method' => $method['name'])), 'admin/content/leaguesite/methods/list', t('Warning! If you have used this scoring method in match results and delete it, it may cause problems with matches that use this score method.'), t('Delete'), t('Cancel'));
  }
  else {
    drupal_not_found();
  }
}

/**
 * Deletes the score method
 */
function leaguesite_score_method_delete_submit($form, $form_state){
  //TODO: I will have to check that this doesn't affect any games. I shouldn't allow people to delete it if it does, because it is not easily undone.
  $method_id = $form_state['values']['method'];
  db_query("DELETE FROM {leaguesite_method} WHERE method_id = %d", $method_id);
  drupal_set_message(t('Method deleted.'));
  drupal_goto('admin/content/leaguesite/methods/list');
}

/**
 * This function gets the current methods assigned to a scoring type and lists them, with options to remove.
 */
function leaguesite_type_methods_view(){
	$type = arg(4);
	if(!is_numeric($type)){
		drupal_not_found();
	}else{
    $methods = db_query("SELECT * FROM {leaguesite_method}, {leaguesite_sport_method} WHERE {leaguesite_sport_method}.method_id = {leaguesite_method}.method_id AND {leaguesite_sport_method}.sport_id = %d;", $type);
    $count = 0;

    while($row = db_fetch_array($methods)){
    	$form[$count]['rid'.$count] = array('#type' => 'hidden', '#value' => $row['rid']);
    	$form[$count]['checkbox'.$count] = array('#type' => 'checkbox');
      $form[$count]['name'.$count] = array('#value' => $row['name'],);
      $form[$count]['points'.$count] = array('#value' => $row['points']);
      ++$count;
    }
    if($count == 0){
      $form['notice'] = array('#value' => 'No scoring types currently exist.');
    }else{
    	$form['submit'] = array(
        '#type' => 'submit',
        '#value' => t('Remove selected'),
    	);
    }
    return $form;
	}
}

/**
 * Theme the list of scoring methods assigned to a scoring type
 */
function theme_leaguesite_type_methods_view($form){
	$type = arg(4);
  $scorerows = array();
  $count = 0;
  foreach ($form as $name => $element) {
    if(is_array($element['name'.$name])){
      $scorerows[] = array(
      drupal_render($element['checkbox'.$name]),
      drupal_render($element['name'.$name]),
      drupal_render($element['points'.$name]),
      );
      unset($form[$name]);
      ++$count;
    }
  }
  $seasonheader = array('', t('Method Name'), t('Points'));
  if(count($scorerows) > 0){
    $output = theme('table', $seasonheader, $scorerows);
  }
  $output .= drupal_render($form);
  $output .= '<br />'.l('Assign a new score method to this sport', 'admin/content/leaguesite/sport/'.$type.'/add/methods');
  return $output;
}

function leaguesite_type_methods_view_submit($form, $form_state){
  for($id = 0; isset($form_state['values']['rid'.$id]); ++$id){
  	if($form_state['values']['checkbox'.$id] == 1){
      db_query('DELETE FROM {leaguesite_sport_method} WHERE rid = %d;', $form_state['values']['rid'.$id]);
      drupal_set_message(t('Method removed'));
  	}
  }
}

/**
 * This function provides a form for a user to add scoring methods to a scoring type. I should get the scoring methods currently created, and list them for the user to select.
 */
function leaguesite_type_methods_add(){
	$type = arg(4);
	//get the score type to clarify to the user what they are doing in the page title
	$name = db_fetch_array(db_query('SELECT name FROM {leaguesite_sports} WHERE sport_id = %d', $type));
	$name = $name['name'];
	drupal_set_title(t('Add scoring method to %sport', array('%sport' => $name)));
	//firstly get the scoring methods
	$all_methods = db_query('SELECT * FROM {leaguesite_method} ORDER BY method_id;');
	//then get the ones which are selected so we can not include them. There should be a way to do this in one query.
	$enabled_methods_result = db_query("SELECT {leaguesite_method}.* FROM {leaguesite_method}, {leaguesite_sport_method} WHERE {leaguesite_sport_method}.method_id = {leaguesite_method}.method_id AND {leaguesite_sport_method}.sport_id = %d ORDER BY {leaguesite_method}.method_id;", $type);
	$enabled_methods = db_fetch_array($enabled_methods_result);
	$count = 0;
	$enabled_count = 0;
	//loop through and add the disabled score types so the list of checkboxes for people to tick and then a submit button at the bottom. Simples.
  while($row = db_fetch_array($all_methods)){
    if($enabled_methods['method_id'] == $row['method_id']){
      //the current row is present in the league.
      $ignore = TRUE;
      ++$enabled_count;
      //get the next enabled one
      $enabled_methods = db_fetch_array($enabled_methods_result);
    }else{
      $ignore = FALSE;
      ++$count;
    }
    if(!$ignore){
      $form['teams'][$row['method_id']] = array(
        '#type' => 'checkbox',
        '#title' => $row['name'].' ('.$row['points'].' points)',
      );
    }
  }
  if($count == 0 && $enabled_count == 0){
    $form['methods']['label'] = array(
      '#value' => t('No score methods added yet, go to ').l(t('add score method'), 'admin/content/leaguesite/methods/add').t(' to add some'),
    );
  }else if($count == 0 && $enabled_count > 0){
  	$form['methods']['label'] = array(
      '#value' => t('All of your score methods are added to this scoring type! To add more methods, go to ').l(t('add score method'), 'admin/content/leaguesite/methods/add'),
    );
  }else{
    $form['submit'] = array(
      '#type' => 'submit', '#value' => t('Add Methods')
    );
  }
  return $form;
}

/**
 * Function to add the score methods to the sport
 * @return unknown_type
 */
function leaguesite_type_methods_add_submit($form, $form_state){
  $type = arg(4);
  if(!is_numeric($type)){
    drupal_not_found();
  }else{
    //loop through the form league values and add the scoring method if checked
    foreach($form_state['values'] as $id => $checked){
      //we don't have to worry about unchecked boxes, just checked ones.
      if($checked == 1){
        //if checked equals 1, then add the relation
        db_query("INSERT INTO {leaguesite_sport_method} (method_id, sport_id) VALUES (%d, %d)", $id, $type);
        //TODO: drupal_set_message(t('Added score method %method to %sport.', array('%method' => $name, '%sport' => $sport_name))); for each type added?
      }
    }
    drupal_set_message("Changes Saved");
  }
}